==> cornerstone-0.3.1.tar.gz: cornerstone-0.3.1/setup.py <==
#!/usr/bin/env python3

# Copyright (c) 2022 Fabrice Laporte - kray.me
# The MIT License http://www.opensource.org/licenses/mit-license.php

import codecs
import os
import re
from setuptools import setup


PKG_NAME = "cornerstone"

# Extract module docstring and version from package root __init__.py
with codecs.open("{}/__init__.py".format(PKG_NAME), encoding="utf-8") as fd:
    metadata = fd.read()
    VERSION = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', metadata, re.MULTILINE
    ).group(1)
    DESCRIPTION = metadata.split('"""')[1].strip()


def read_rsrc(filename, pypi_compat=False):
    """Return content of given text file.
    If `.. pypi` comment if present then remove emojis in whole text and
    anything preceding the comment so that the .rst can be properly displayed
    on pypi.
    """
    with codecs.open(filename, encoding="utf-8") as _file:
        data = _file.read().strip()
        if pypi_compat or filename == "README.md":
            if ".. pypi" in data:
                data = re.sub(r":(\w+\\?)+:", "", data[data.find(".. pypi") :] or data)
    return data


setup(
    name=PKG_NAME,
    version=VERSION,
    description="",
    long_description=read_rsrc("README.md"),
    long_description_content_type="text/markdown",
    author="Fabrice Laporte",
    author_email="kraymer@gmail.com",
    url=f"https://github.com/KraYmer/{PKG_NAME}",
    license="MIT",
    platforms="ALL",
    packages=[PKG_NAME],
    install_requires=read_rsrc("requirements.txt").split("\n"),
    python_requires=">=3.6",
    extras_require={
        "test": [
            "coverage>5",
            "pytest>=6",
            "tox>=3",
        ]
    },
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
    ],
    keywords="",
)

==> cornerstone-0.4.0.tar.gz: cornerstone-0.4.0/setup.py <==
#!/usr/bin/env python3

# Copyright (c) 2022 Fabrice Laporte - kray.me
# The MIT License http://www.opensource.org/licenses/mit-license.php

import codecs
import os
import re
from setuptools import setup


PKG_NAME = "cornerstone"

# Extract module docstring and version from package root __init__.py
with codecs.open("{}/__init__.py".format(PKG_NAME), encoding="utf-8") as fd:
    metadata = fd.read()
    VERSION = re.search(
        r'^__version__\s*=\s*[\'"]([^\'"]*)[\'"]', metadata, re.MULTILINE
    ).group(1)
    DESCRIPTION = metadata.split('"""')[1].strip()


def read_rsrc(filename, pypi_compat=False):
    """Return content of given text file.
    If pypi_compat is True then remove lines that contain the string "nopypi"
    """
    with codecs.open(filename, encoding="utf-8") as _file:
        lines = _file.readlines()
        if pypi_compat:
            lines = [x for x in lines if "[nopypi]" not in x]
        return "".join(lines).strip()


setup(
    name=PKG_NAME,
    version=VERSION,
    description="",
    long_description=read_rsrc("README.md", True),
    long_description_content_type="text/markdown",
    author="Fabrice Laporte",
    author_email="kraymer@gmail.com",
    url=f"https://github.com/KraYmer/{PKG_NAME}",
    license="MIT",
    platforms="ALL",
    packages=[PKG_NAME],
    install_requires=read_rsrc("requirements.txt").split("\n"),
    python_requires=">=3.6",
    extras_require={
        "test": [
            "coverage>5",
            "pytest>=6",
            "tox>=3",
        ]
    },
    classifiers=[
        "Programming Language :: Python",
        "License :: OSI Approved :: MIT License",
    ],
    keywords="",
)
